require_relative 'pod'

module Pod

  class LocalSpec
    @@local_spec_importing = false
    @@local_spec_path = nil
    def self.import_local_pod(path)
      @@local_spec_importing = true
      @@local_spec_path = path
      yield if block_given?
      @@local_spec_path = nil
      @@local_spec_importing = false
    end
    def self.local_spec_importing?
      @@local_spec_importing
    end
    def self.local_spec_path
      @@local_spec_path
    end
  end

  class Podfile

    # 只在 debug 模式下集成的组件，默认为空
    @@debug_only_pods = []

    # 导入工程目录下相对位置的 pod
    def import_relative_in(path = './')
      LocalSpec.import_local_pod(path) do
        yield if block_given?
      end
    end
    
    original_pod = instance_method(:pod)
    define_method(:pod) do |name = nil, *requirements|

      if Pod::Podfile::is_release_mode?
        realname = name.split('/').first
        if @@debug_only_pods.include?(realname)
          puts "#{realname} is only for debug, it will be removed."
          next
        end
      end

      if LocalSpec.local_spec_importing?
        path_cfg = { :path => "#{LocalSpec.local_spec_path}/#{Pod::repo_name(name)}" }
        if requirements.length == 0
          requirements = [path_cfg]
        else
          cfg = requirements.first
          cfg.merge!(path_cfg) unless cfg.has_key?(:path)
        end
      end
      original_pod.bind(self).(name, *requirements)
    end

  end

end
